@@ -1,22 +1,30 @@
-#' Install a cffr GitHub Action
+#' Install a \CRANpkg{cffr} GitHub Action
 #'
 #' @description
 #'
-#' This function would install a GitHub Action on your repo. The action
-#' will update your `CITATION.cff` when any of these events occur:
+#' This function would install a [GitHub
+#' Action](https://github.com/features/actions) on your repo. The action will
+#' update your `CITATION.cff` when any of these events occur:
 #' - You publish a new release of the package.
-#' - Your DESCRIPTION or inst/CITATION are modified.
+#' - Your `DESCRIPTION` or `inst/CITATION` are modified.
 #' - The action can be run also manually.
 #'
-#' @param path Project directory
-#' @param overwrite If already present, do you want to overwrite your action?
+#' @param path Project root directory.
+#' @param overwrite Logical. If already present, do you want to overwrite your
+#'   action?
 #'
 #' @return Invisible, this function is called by its side effects.
 #'
 #' @details
 #'
 #' Triggers on your action can be modified, see
-#' [Events that trigger workflows](https://docs.github.com/en/actions/learn-github-actions/events-that-trigger-workflows).
+#' ```{r, echo=FALSE, results='asis'}
+#'
+#' cat(paste0(" [Events that trigger workflows]",
+#'            "(https://docs.github.com/en/actions/learn-github-actions/",
+#'            "events-that-trigger-workflows)."))
+#'
+#' ```
 #'
 #' @examples
 #' \dontrun{
@@ -37,10 +45,9 @@ cff_gha_update <- function(path = ".",
 
   newfile <- file.path(destdir, "update-citation-cff.yaml")
 
-  if (!file.exists(newfile) || isTRUE(overwrite)) {
-    cli::cli_alert_success(
-      "Installing {.file {newfile}}"
-    )
+  if (!file_exist_abort(newfile) || isTRUE(overwrite)) {
+    cli::cli_alert_success("Installing {.file {newfile}}")
+
     file.copy(system.file("yaml/update-citation-cff.yaml", package = "cffr"),
       newfile,
       overwrite = TRUE
@@ -54,7 +61,7 @@ cff_gha_update <- function(path = ".",
     )
   }
 
-  if (file.exists(file.path(path, ".Rbuildignore"))) {
+  if (file_exist_abort(file.path(path, ".Rbuildignore"))) {
     ignore <- readLines(file.path(path, ".Rbuildignore"))
 
     # If not already
