@@ -1,4 +1,4 @@
-## ---- include = FALSE-------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -6,7 +6,7 @@ knitr::opts_chunk$set(
 
 library(cffr)
 
-## ----summary , echo=FALSE---------------------------------
+## ----summary , echo=FALSE-----------------------------------------------------
 keys <- cff_schema_keys(sorted = TRUE)
 origin <- vector(length = length(keys))
 origin[keys == "cff-version"] <- "parameter on function"
@@ -35,7 +35,7 @@ origin[keys %in% c(
 )] <- "CITATION file"
 
 
-origin[origin == FALSE] <- "Not parsed by cffr"
+origin[origin == FALSE] <- "Ignored by cffr"
 
 df <- data.frame(
   key = paste0("<a href='#", keys, "'>", keys, "</a>"),
@@ -45,7 +45,7 @@ df <- data.frame(
 
 knitr::kable(df, escape = FALSE)
 
-## ----abstract---------------------------------------------
+## ----abstract-----------------------------------------------------------------
 library(cffr)
 
 # Create cffr for yaml
@@ -60,7 +60,7 @@ cat(cff_obj$abstract)
 
 cat(pkg$get("Description"))
 
-## ----authors----------------------------------------------
+## ----authors------------------------------------------------------------------
 # An example DESCRIPTION
 path <- system.file("examples/DESCRIPTION_many_persons", package = "cffr")
 pkg <- desc::desc(path)
@@ -78,12 +78,12 @@ cff_obj$authors
 cff_obj_alt <- cff_create(path, authors_roles = c("cre", "cph"))
 cff_obj_alt$authors
 
-## ----cffversion-------------------------------------------
+## ----cffversion---------------------------------------------------------------
 cff_objv110 <- cff_create("jsonlite", cff_version = "v1.1.0")
 
 cat(cff_objv110$`cff-version`)
 
-## ----contact----------------------------------------------
+## ----contact------------------------------------------------------------------
 cff_obj <- cff_create("rmarkdown")
 pkg <- desc::desc(file.path(find.package("rmarkdown"), "DESCRIPTION"))
 
@@ -91,7 +91,7 @@ cff_obj$contact
 
 pkg$get_author()
 
-## ----date-released----------------------------------------
+## ----date-released------------------------------------------------------------
 # From an installed package
 
 cff_obj <- cff_create("rmarkdown")
@@ -127,14 +127,14 @@ desc::desc_set("Date", "1999-01-01", file = tmp)
 
 cat(cff_create(tmp)$`date-released`)
 
-## ----doi--------------------------------------------------
+## ----doi----------------------------------------------------------------------
 cff_doi <- cff_create("cffr")
 
 cat(cff_doi$doi)
 
 cat(cff_doi$`preferred-citation`$doi)
 
-## ----identifiers------------------------------------------
+## ----identifiers--------------------------------------------------------------
 file <- system.file("examples/DESCRIPTION_many_urls", package = "cffr")
 
 pkg <- desc::desc(file)
@@ -147,7 +147,7 @@ cat(cff_create(file)$`repository-code`)
 
 cff_create(file)$identifiers
 
-## ----keyword----------------------------------------------
+## ----keyword------------------------------------------------------------------
 # A DESCRIPTION file without keywords
 nokeywords <- system.file("examples/DESCRIPTION_basic", package = "cffr")
 tmp2 <- tempfile("DESCRIPTION")
@@ -172,7 +172,7 @@ desc::desc_set("X-schema.org-keywords", "keyword1, keyword2, keyword3",
 
 cat(cff_create(tmp2)$keywords)
 
-## ----ghkeyword--------------------------------------------
+## ----ghkeyword----------------------------------------------------------------
 # Get cff object from jsonvalidate
 
 jsonval <- cff_create("jsonvalidate")
@@ -187,7 +187,7 @@ jsonval$keywords
 # The repo
 jsonval$`repository-code`
 
-## ----license----------------------------------------------
+## ----license------------------------------------------------------------------
 cff_obj <- cff_create("yaml")
 
 cat(cff_obj$license)
@@ -196,31 +196,31 @@ pkg <- desc::desc(file.path(find.package("yaml"), "DESCRIPTION"))
 
 cat(pkg$get("License"))
 
-## ----eval=FALSE-------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  msg <- paste0(
 #    'To cite package "',
 #    "NAME_OF_THE_PACKAGE",
 #    '" in publications use:'
 #  )
 
-## ----message----------------------------------------------
+## ----message------------------------------------------------------------------
 cat(cff_create("jsonlite")$message)
 
-## ----preferred-citation-----------------------------------
+## ----preferred-citation-------------------------------------------------------
 cffobj <- cff_create("rmarkdown")
 
 cffobj$`preferred-citation`
 
 citation("rmarkdown")[1]
 
-## ----references-------------------------------------------
+## ----references---------------------------------------------------------------
 cffobj <- cff_create("rmarkdown")
 
 cffobj$references
 
 citation("rmarkdown")[-1]
 
-## ----repository-------------------------------------------
+## ----repository---------------------------------------------------------------
 # Installed package
 
 inst <- cff_create("jsonlite")
@@ -256,34 +256,7 @@ desc::desc_set("Package", "ggplot2", file = tmp)
 
 cat(cff_create(tmp)[["repository"]])
 
-# Show what happens if another repo is set
-
-# Save original config
-orig_options <- options()
-getOption("repos")
-
-
-# Set new repos
-options(repos = c(
-  tidyverse = "https://tidyverse.r-universe.dev",
-  CRAN = "https://cloud.r-project.org"
-))
-
-# Load again the library
-# Repos are evaluated on load
-unloadNamespace("cffr")
-library(cffr)
-
-
-cat(cff_create(tmp)[["repository"]])
-
-# Now it is the tidyverse repo, due to our new config!
-
-# Reset original config
-options(orig_options)
-getOption("repos")
-
-## ----repository-code--------------------------------------
+## ----repository-code----------------------------------------------------------
 # Installed package on GitHub
 
 cff_create("jsonlite")$`repository-code`
@@ -301,19 +274,19 @@ cat(cff_create(gitlab)$`repository-code`)
 
 desc::desc(gitlab)
 
-## ----eval=FALSE-------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  title <- paste0(
 #    "NAME_OF_THE_PACKAGE",
 #    ": ",
 #    "TITLE_OF_THE_PACKAGE"
 #  )
 
-## ----title------------------------------------------------
+## ----title--------------------------------------------------------------------
 # Installed package
 
 cat(cff_create("testthat")$title)
 
-## ----url--------------------------------------------------
+## ----url----------------------------------------------------------------------
 # Many urls
 manyurls <- system.file("examples/DESCRIPTION_many_urls", package = "cffr")
 
@@ -323,7 +296,7 @@ cat(cff_create(manyurls)$url)
 
 desc::desc(manyurls)
 
-## ----version----------------------------------------------
+## ----version------------------------------------------------------------------
 # Should be (>= 3.0.0)
 cat(cff_create("testthat")$version)
 
