@@ -6,13 +6,13 @@ test_that("Write basic", {
   tmp <- tempfile(fileext = ".cff")
   expect_message(cff_write(desc_file, outfile = tmp, validate = FALSE))
   expect_silent(cff_write(desc_file, outfile = tmp, verbose = FALSE))
-  expect_true(file.exists(tmp))
+  expect_true(file_exist_abort(tmp))
 
   # Validate from file
   expect_true(cff_validate(tmp, verbose = FALSE))
 
   file.remove(tmp)
-  expect_false(file.exists(tmp))
+  expect_false(file_exist_abort(tmp))
 })
 
 test_that("Write to a non-existing folder", {
@@ -31,13 +31,13 @@ test_that("Write to a non-existing folder", {
   expect_true(dir.exists(file.path(
     tempdir(), "test_new_folder", "recursive"
   )))
-  expect_true(file.exists(tmp))
+  expect_true(file_exist_abort(tmp))
 
   # Validate from file
   expect_true(cff_validate(tmp, verbose = FALSE))
 
   file.remove(tmp)
-  expect_false(file.exists(tmp))
+  expect_false(file_exist_abort(tmp))
 })
 
 test_that("Write no encoding", {
@@ -53,13 +53,13 @@ test_that("Write no encoding", {
     verbose = FALSE
   )
 
-  expect_true(file.exists(tmp))
+  expect_true(file_exist_abort(tmp))
 
   # Validate from file
   expect_true(cff_validate(tmp, verbose = FALSE))
 
   file.remove(tmp)
-  expect_false(file.exists(tmp))
+  expect_false(file_exist_abort(tmp))
 })
 
 test_that("Add new keys", {
@@ -75,10 +75,9 @@ test_that("Add new keys", {
     message = "This overwrites fields",
     abstract = "New abstract",
     keywords = c("A", "new", "list", "of", "keywords"),
-    authors = list(cff_parse_person(person(
-      "Don", "Nadie",
-      comment = c(website = "error")
-    ))),
+    authors = as_cff_person(
+      person("Don", "Nadie", comment = c(website = "error"))
+    ),
     "date-released" = "1900-01-01",
     "error" = "This is an error"
   )
@@ -93,13 +92,13 @@ test_that("Add new keys", {
   )
   expect_snapshot(s)
 
-  expect_true(file.exists(tmp))
+  expect_true(file_exist_abort(tmp))
 
   # Validate from file
   expect_true(cff_validate(tmp, verbose = FALSE))
 
   file.remove(tmp)
-  expect_false(file.exists(tmp))
+  expect_false(file_exist_abort(tmp))
 })
 
 
@@ -117,15 +116,14 @@ test_that("Append keys", {
   # It should be a list
   new_aut <- append(
     old_aut,
-    list(cff_parse_person(person(
-      "New",
-      "author",
-      comment = c(
-        "error" = 123,
-        website = "https://stackoverflow.com/",
-        country = "IT"
+    as_cff_person(
+      person("New", "author",
+        comment = c(
+          "error" = 123, website = "https://stackoverflow.com/",
+          country = "IT"
+        )
       )
-    )))
+    )
   )
 
   tmp <- tempfile(fileext = ".cff")
@@ -141,7 +139,7 @@ test_that("Append keys", {
   expect_true(cff_validate(tmp, verbose = FALSE))
 
   file.remove(tmp)
-  expect_false(file.exists(tmp))
+  expect_false(file_exist_abort(tmp))
 })
 
 test_that("Fix extension of the file", {
@@ -150,10 +148,10 @@ test_that("Fix extension of the file", {
   tmp <- tempfile()
   expect_silent(cff_write(cffobj, tmp, verbose = FALSE))
 
-  expect_false(file.exists(tmp))
-  expect_true(file.exists(paste0(tmp, ".cff")))
+  expect_false(file_exist_abort(tmp))
+  expect_true(file_exist_abort(paste0(tmp, ".cff")))
   expect_true(cff_validate(paste0(tmp, ".cff"), verbose = FALSE))
 
   file.remove(paste0(tmp, ".cff"))
-  expect_false(file.exists(paste0(tmp, ".cff")))
+  expect_false(file_exist_abort(paste0(tmp, ".cff")))
 })
